@@ -1,4 +1,4 @@
-use std::{cell::RefCell, rc::Rc};
+use std::{cell::RefCell, collections::HashSet, rc::Rc};
 
 use anyhow::Result;
 use gag::Gag;
@@ -56,7 +56,8 @@ impl Jnv {
                 } else {
                     segments
                         .iter()
-                        .map(|segment| match segment {
+                        .enumerate()
+                        .map(|(i, segment)| match segment {
                             JsonPathSegment::Key(key) => {
                                 if key.contains('.') || key.contains('-') || key.contains('@') {
                                     format!(".\"{}\"", key)
@@ -64,7 +65,13 @@ impl Jnv {
                                     format!(".{}", key)
                                 }
                             }
-                            JsonPathSegment::Index(index) => format!("[{}]", index),
+                            JsonPathSegment::Index(index) => {
+                                if i == 0 {
+                                    format!(".[{}]", index)
+                                } else {
+                                    format!("[{}]", index)
+                                }
+                            }
                         })
                         .collect::<String>()
                 }
@@ -83,6 +90,7 @@ impl Jnv {
                 active_char_style: StyleBuilder::new().bgc(Color::Magenta).build(),
                 inactive_char_style: StyleBuilder::new().build(),
                 edit_mode,
+                word_break_chars: HashSet::from(['.', '|', '(', ')', '[', ']']),
                 lines: Default::default(),
             },
             hint_message_renderer: text::Renderer {
